@@ -15,17 +15,15 @@
 
 import sys
 
-import eventlet
-
-eventlet.monkey_patch()
-
 from neutron.agent.common import config
+from neutron.agent.linux import external_process
 from neutron.agent.linux import interface
 from neutron.common import config as common_config
 from neutron.common import rpc as n_rpc
 from oslo_config import cfg
 from oslo_service import service
 
+from neutron_lbaas._i18n import _
 from neutron_lbaas.agent import agent_manager as manager
 from neutron_lbaas.services.loadbalancer import constants
 
@@ -54,6 +52,7 @@ def main():
     cfg.CONF.register_opts(manager.OPTS)
     # import interface options just in case the driver uses namespaces
     cfg.CONF.register_opts(interface.OPTS)
+    cfg.CONF.register_opts(external_process.OPTS)
     config.register_interface_driver_opts_helper(cfg.CONF)
     config.register_agent_state_opts_helper(cfg.CONF)
     config.register_root_helper(cfg.CONF)
