@@ -13,11 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
-from neutron.api.v2 import attributes as attr
-from neutron.db import model_base
+from neutron.db.models import servicetype as st_db
 from neutron.db import models_v2
-from neutron.db import servicetype_db as st_db
+from neutron_lib.db import constants as db_const
+from neutron_lib.db import model_base
 import sqlalchemy as sa
 from sqlalchemy.ext import orderinglist
 from sqlalchemy import orm
@@ -67,7 +66,7 @@ class LoadBalancerStatistics(model_base.BASEV2):
         return value
 
 
-class MemberV2(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class MemberV2(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     """Represents a v2 neutron load balancer member."""
 
     NAME = 'member'
@@ -87,14 +86,15 @@ class MemberV2(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
     subnet_id = sa.Column(sa.String(36), nullable=True)
     provisioning_status = sa.Column(sa.String(16), nullable=False)
     operating_status = sa.Column(sa.String(16), nullable=False)
-    name = sa.Column(sa.String(attr.NAME_MAX_LEN), nullable=True)
+    name = sa.Column(sa.String(db_const.NAME_FIELD_SIZE), nullable=True)
 
     @property
     def root_loadbalancer(self):
         return self.pool.loadbalancer
 
 
-class HealthMonitorV2(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class HealthMonitorV2(model_base.BASEV2, model_base.HasId,
+                      model_base.HasProject):
     """Represents a v2 neutron load balancer healthmonitor."""
 
     NAME = 'healthmonitor'
@@ -112,14 +112,15 @@ class HealthMonitorV2(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
     expected_codes = sa.Column(sa.String(64), nullable=True)
     provisioning_status = sa.Column(sa.String(16), nullable=False)
     admin_state_up = sa.Column(sa.Boolean(), nullable=False)
-    name = sa.Column(sa.String(attr.NAME_MAX_LEN), nullable=True)
+    name = sa.Column(sa.String(db_const.NAME_FIELD_SIZE), nullable=True)
+    max_retries_down = sa.Column(sa.Integer, nullable=True)
 
     @property
     def root_loadbalancer(self):
         return self.pool.loadbalancer
 
 
-class LoadBalancer(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class LoadBalancer(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     """Represents a v2 neutron load balancer."""
 
     NAME = 'loadbalancer'
@@ -161,7 +162,7 @@ class LoadBalancer(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
         return self
 
 
-class PoolV2(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class PoolV2(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     """Represents a v2 neutron load balancer pool."""
 
     NAME = 'pool'
@@ -242,7 +243,7 @@ class SNI(model_base.BASEV2):
         return self.listener.loadbalancer
 
 
-class L7Rule(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class L7Rule(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     """Represents L7 Rule."""
 
     NAME = 'l7rule'
@@ -269,7 +270,7 @@ class L7Rule(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
         return self.policy.listener.loadbalancer
 
 
-class L7Policy(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class L7Policy(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     """Represents L7 Policy."""
 
     NAME = 'l7policy'
@@ -310,7 +311,7 @@ class L7Policy(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
         return self.listener.loadbalancer
 
 
-class Listener(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class Listener(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     """Represents a v2 neutron listener."""
 
     NAME = 'listener'
