@@ -25,7 +25,7 @@ from oslo_service import service
 
 from neutron_lbaas._i18n import _, _LE
 from neutron_lbaas.drivers import driver_base
-from neutron_lbaas.drivers.driver_mixins import BaseManagerMixin
+from neutron_lbaas.drivers import driver_mixins
 from neutron_lbaas.services.loadbalancer.drivers.netscaler import ncc_client
 
 DEFAULT_PERIODIC_TASK_INTERVAL = "2"
@@ -330,7 +330,7 @@ class NetScalerLoadBalancerDriverV2(driver_base.LoadBalancerBaseDriver):
         return
 
 
-class NetScalerCommonManager(BaseManagerMixin):
+class NetScalerCommonManager(driver_mixins.BaseManagerMixin):
 
     def __init__(self, driver):
         super(NetScalerCommonManager, self).__init__(driver)
@@ -351,9 +351,9 @@ class NetScalerCommonManager(BaseManagerMixin):
                 self.successful_completion(context, obj)
             else:
                 self.track_provision_status(obj)
-        except Exception as e:
+        except Exception:
             self.failed_completion(context, obj)
-            raise e
+            raise
 
     def update(self, context, old_obj, obj):
         LOG.debug("%s, update %s", self.__class__.__name__, old_obj.id)
@@ -363,9 +363,9 @@ class NetScalerCommonManager(BaseManagerMixin):
                 self.successful_completion(context, obj)
             else:
                 self.track_provision_status(obj)
-        except Exception as e:
+        except Exception:
             self.failed_completion(context, obj)
-            raise e
+            raise
 
     def delete(self, context, obj):
         LOG.debug("%s, delete %s", self.__class__.__name__, obj.id)
@@ -375,9 +375,9 @@ class NetScalerCommonManager(BaseManagerMixin):
                 self.successful_completion(context, obj, delete=True)
             else:
                 self.track_provision_status(obj)
-        except Exception as e:
+        except Exception:
             self.failed_completion(context, obj)
-            raise e
+            raise
 
     def track_provision_status(self, obj):
         for lb in self._get_loadbalancers(obj):
@@ -422,7 +422,7 @@ class NetScalerLoadBalancerManager(NetScalerCommonManager,
         vip_subnet_id = lb_obj.vip_subnet_id
         network_info = self.payload_preparer.\
             get_network_info(context, self.driver.plugin, vip_subnet_id)
-        ncc_lb = dict(ncc_lb.items() + network_info.items())
+        ncc_lb.update(network_info)
         msg = _("NetScaler driver lb creation: %s") % repr(ncc_lb)
         LOG.debug(msg)
         resource_path = "%s/%s" % (RESOURCE_PREFIX, LBS_RESOURCE)
@@ -545,7 +545,7 @@ class NetScalerMemberManager(NetScalerCommonManager,
         network_info = (self.payload_preparer.
                         get_network_info(context, self.driver.plugin,
                                          subnet_id))
-        ncc_member = dict(ncc_member.items() + network_info.items())
+        ncc_member.update(network_info)
         msg = _("NetScaler driver member creation: %s") % repr(ncc_member)
         LOG.debug(msg)
         parent_pool_id = member.pool.id
