@@ -14,15 +14,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron_lib.api import converters
+from neutron_lib.api import extensions as api_extensions
+from neutron_lib import constants as n_constants
+from neutron_lib.db import constants as db_const
+from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import directory
+
 from neutron.api import extensions
-from neutron.api.v2 import attributes as attr
 from neutron.api.v2 import base
 from neutron.api.v2 import resource_helper
-from neutron import manager
 from neutron.plugins.common import constants
-from neutron_lib.api import converters
-from neutron_lib import constants as n_constants
-from neutron_lib import exceptions as nexception
 
 from neutron_lbaas._i18n import _
 from neutron_lbaas.extensions import loadbalancerv2
@@ -79,7 +81,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:string': attr.NAME_MAX_LEN},
+                      'validate': {'type:string': db_const.NAME_FIELD_SIZE},
                       'required_by_policy': True,
                       'is_visible': True},
         'name': {'allow_post': True, 'allow_put': True,
@@ -87,7 +89,8 @@ RESOURCE_ATTRIBUTE_MAP = {
                  'default': '',
                  'is_visible': True},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {'type:string': attr.DESCRIPTION_MAX_LEN},
+                        'validate': {
+                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
                         'is_visible': True, 'default': ''},
         'listener_id': {'allow_post': True, 'allow_put': False,
                         'validate': {'type:uuid': None},
@@ -166,7 +169,7 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
 }
 
 
-class L7(extensions.ExtensionDescriptor):
+class L7(api_extensions.ExtensionDescriptor):
 
     @classmethod
     def get_name(cls):
@@ -193,7 +196,6 @@ class L7(extensions.ExtensionDescriptor):
 
     def get_resources(cls):
         l7_plurals = {'l7policies': 'l7policy', 'rules': 'rule'}
-        attr.PLURALS.update(l7_plurals)
 
         plural_mappings = resource_helper.build_plural_mappings(
             l7_plurals, RESOURCE_ATTRIBUTE_MAP)
@@ -204,8 +206,7 @@ class L7(extensions.ExtensionDescriptor):
             constants.LOADBALANCERV2,
             register_quota=True)
 
-        plugin = manager.NeutronManager.get_service_plugins()[
-            constants.LOADBALANCERV2]
+        plugin = directory.get_plugin(constants.LOADBALANCERV2)
 
         for collection_name in SUB_RESOURCE_ATTRIBUTE_MAP:
             # Special handling needed for sub-resources with 'y' ending
