@@ -15,17 +15,19 @@
 
 import abc
 
+from neutron_lib.api import extensions as api_extensions
+from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import directory
+
 from neutron.api import extensions
 from neutron.api.v2 import base
 from neutron.api.v2 import resource
 from neutron.extensions import agent
-from neutron import manager
 from neutron.plugins.common import constants as plugin_const
 from neutron import policy
 from neutron import wsgi
 
 from neutron_lbaas._i18n import _
-from neutron_lbaas.extensions import loadbalancer
 from neutron_lbaas.extensions import loadbalancerv2
 from neutron_lbaas.services.loadbalancer import constants as lb_const
 
@@ -36,8 +38,7 @@ LOADBALANCER_AGENT = 'loadbalancer-hosting-agent'
 
 class LoadBalancerSchedulerController(wsgi.Controller):
     def index(self, request, **kwargs):
-        lbaas_plugin = manager.NeutronManager.get_service_plugins().get(
-            plugin_const.LOADBALANCERV2)
+        lbaas_plugin = directory.get_plugin(plugin_const.LOADBALANCERV2)
         if not lbaas_plugin:
             return {'load_balancers': []}
 
@@ -52,8 +53,7 @@ class LoadBalancerSchedulerController(wsgi.Controller):
 
 class LbaasAgentHostingLoadBalancerController(wsgi.Controller):
     def index(self, request, **kwargs):
-        lbaas_plugin = manager.NeutronManager.get_service_plugins().get(
-            plugin_const.LOADBALANCERV2)
+        lbaas_plugin = directory.get_plugin(plugin_const.LOADBALANCERV2)
         if not lbaas_plugin:
             return
 
@@ -65,7 +65,7 @@ class LbaasAgentHostingLoadBalancerController(wsgi.Controller):
             request.context, kwargs['loadbalancer_id'])
 
 
-class Lbaas_agentschedulerv2(extensions.ExtensionDescriptor):
+class Lbaas_agentschedulerv2(api_extensions.ExtensionDescriptor):
     """Extension class supporting LBaaS agent scheduler.
     """
 
@@ -115,7 +115,11 @@ class Lbaas_agentschedulerv2(extensions.ExtensionDescriptor):
         return {}
 
 
-class NoEligibleLbaasAgent(loadbalancer.NoEligibleBackend):
+class NoEligibleBackend(nexception.NotFound):
+    message = _("No eligible backend for pool %(pool_id)s")
+
+
+class NoEligibleLbaasAgent(NoEligibleBackend):
     message = _("No eligible agent found "
                 "for loadbalancer %(loadbalancer_id)s.")
 
