@@ -34,7 +34,7 @@ class TestHealthMonitors(base.BaseTestCase):
     @classmethod
     def resource_setup(cls):
         super(TestHealthMonitors, cls).resource_setup()
-        if not test.is_extension_enabled('lbaas', 'network'):
+        if not test.is_extension_enabled('lbaasv2', 'network'):
             msg = "lbaas extension not enabled."
             raise cls.skipException(msg)
         network_name = data_utils.rand_name('network-')
