@@ -1,4 +1,5 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
+# Copyright 2016 Rackspace Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,18 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
-from tempest_lib.common.utils import data_utils
-from tempest_lib import exceptions as ex
+from tempest.lib.common.utils import data_utils
+from tempest.lib import exceptions as ex
+from tempest import test
 
-from neutron_lbaas.tests.tempest.lib import config
-from neutron_lbaas.tests.tempest.lib import test
 from neutron_lbaas.tests.tempest.v2.api import base
 
-CONF = config.CONF
-
-LOG = logging.getLogger(__name__)
-
 
 class ListenersTestJSON(base.BaseAdminTestCase):
 
@@ -37,7 +32,7 @@ class ListenersTestJSON(base.BaseAdminTestCase):
     @classmethod
     def resource_setup(cls):
         super(ListenersTestJSON, cls).resource_setup()
-        if not test.is_extension_enabled('lbaas', 'network'):
+        if not test.is_extension_enabled('lbaasv2', 'network'):
             msg = "lbaas extension not enabled."
             raise cls.skipException(msg)
         network_name = data_utils.rand_name('network-')
@@ -61,7 +56,7 @@ class ListenersTestJSON(base.BaseAdminTestCase):
     def resource_cleanup(cls):
         super(ListenersTestJSON, cls).resource_cleanup()
 
-    @test.attr(type='smoke')
+    @test.attr(type='negative')
     def test_create_listener_empty_tenant_id(self):
         """Test create listener with an empty tenant id should fail"""
         create_new_listener_kwargs = self.create_listener_kwargs
@@ -74,7 +69,6 @@ class ListenersTestJSON(base.BaseAdminTestCase):
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id])
 
-    @test.attr(type='smoke')
     def test_create_listener_invalid_tenant_id(self):
         """Test create listener with an invalid tenant id"""
         create_new_listener_kwargs = self.create_listener_kwargs
@@ -83,13 +77,13 @@ class ListenersTestJSON(base.BaseAdminTestCase):
         new_listener = self._create_listener(
             **create_new_listener_kwargs)
         new_listener_id = new_listener['id']
+        self.addCleanup(self._delete_listener, new_listener_id)
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id, new_listener_id])
         listener = self.listeners_client.get_listener(
             new_listener_id)
         self.assertEqual(new_listener, listener)
-        self._delete_listener(new_listener_id)
 
     @test.attr(type='smoke')
     def test_create_listener_missing_tenant_id(self):
@@ -104,6 +98,7 @@ class ListenersTestJSON(base.BaseAdminTestCase):
         admin_listener = self._create_listener(
             **create_new_listener_kwargs)
         admin_listener_id = admin_listener['id']
+        self.addCleanup(self._delete_listener, admin_listener_id)
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id, admin_listener_id])
@@ -112,4 +107,3 @@ class ListenersTestJSON(base.BaseAdminTestCase):
         self.assertEqual(admin_listener, listener)
         self.assertEqual(admin_listener.get('tenant_id'),
                          listener.get('tenant_id'))
-        self._delete_listener(admin_listener_id)
