@@ -16,11 +16,10 @@
 import mock
 
 from neutron import context
-from neutron.extensions import portbindings
 from neutron.plugins.common import constants
 from neutron.tests.unit import testlib_api
+from neutron_lib.api.definitions import portbindings
 from oslo_utils import uuidutils
-import six
 from six import moves
 
 from neutron_lbaas.db.loadbalancer import loadbalancer_dbv2 as ldb
@@ -178,7 +177,7 @@ class TestLoadBalancerCallbacks(
             db_lb = self.plugin_instance.db.get_loadbalancer(ctx, lb_id)
             func(ctx, port_id=db_lb.vip_port_id, **kwargs)
             db_port = core.get_port(ctx, db_lb.vip_port_id)
-            for k, v in six.iteritems(expected):
+            for k, v in expected.items():
                 self.assertEqual(v, db_port[k])
 
     def test_plug_vip_port(self):
