@@ -17,12 +17,14 @@ import collections
 import socket
 
 import mock
+from neutron.agent.linux import external_process
 from neutron.plugins.common import constants
 from neutron_lib import exceptions
 
 from neutron_lbaas.drivers.haproxy import namespace_driver
 from neutron_lbaas.services.loadbalancer import data_models
 from neutron_lbaas.tests import base
+from oslo_utils import fileutils
 
 
 class TestHaproxyNSDriver(base.BaseTestCase):
@@ -37,11 +39,14 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         conf.haproxy.send_gratuitous_arp = 3
         self.conf = conf
         self.rpc_mock = mock.Mock()
+        self.ensure_dir = mock.patch.object(fileutils, 'ensure_tree').start()
+        self._process_monitor = mock.Mock()
         with mock.patch(
                 'neutron.common.utils.load_class_by_alias_or_classname'):
             self.driver = namespace_driver.HaproxyNSDriver(
                 conf,
-                self.rpc_mock
+                self.rpc_mock,
+                self._process_monitor
             )
         self.vif_driver = mock.Mock()
         self.driver.vif_driver = self.vif_driver
@@ -66,19 +71,17 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         self.assertEqual(namespace_driver.DRIVER_NAME, self.driver.get_name())
 
     @mock.patch('neutron.agent.linux.ip_lib.IPWrapper')
+    @mock.patch('os.makedirs')
     @mock.patch('os.path.dirname')
     @mock.patch('os.path.isdir')
     @mock.patch('shutil.rmtree')
     def test_undeploy_instance(self, mock_shutil, mock_isdir, mock_dirname,
-                               mock_ip_wrap):
+                               mock_makedirs, mock_ip_wrap):
         self.driver._get_state_file_path = mock.Mock(return_value='/path')
-        namespace_driver.kill_pids_in_file = mock.Mock()
         self.driver._unplug = mock.Mock()
         mock_dirname.return_value = '/path/' + self.lb.id
         mock_isdir.return_value = False
-
         self.driver.undeploy_instance(self.lb.id)
-        namespace_driver.kill_pids_in_file.assert_called_once_with('/path')
         calls = [mock.call(self.lb.id, 'pid'), mock.call(self.lb.id, '')]
         self.driver._get_state_file_path.has_calls(calls)
         self.assertFalse(self.driver._unplug.called)
@@ -88,7 +91,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
 
         self.driver.deployed_loadbalancers[self.lb.id] = self.lb
         mock_isdir.return_value = True
-        namespace_driver.kill_pids_in_file.reset_mock()
         mock_isdir.reset_mock()
         mock_ns = mock_ip_wrap.return_value
         mock_ns.get_devices.return_value = [collections.namedtuple(
@@ -96,7 +98,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         self.driver.undeploy_instance(self.lb.id, cleanup_namespace=True,
                                       delete_namespace=True)
         ns = namespace_driver.get_ns_name(self.lb.id)
-        namespace_driver.kill_pids_in_file.assert_called_once_with('/path')
         calls = [mock.call(self.lb.id, 'pid'), mock.call(self.lb.id, '')]
         self.driver._get_state_file_path.has_calls(calls)
         self.driver._unplug.assert_called_once_with(ns, self.lb.vip_port)
@@ -108,6 +109,19 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         mock_shutil.assert_called_once_with('/path/' + self.lb.id)
         mock_ns.garbage_collect_namespace.assert_called_once_with()
 
+    @mock.patch('os.makedirs')
+    @mock.patch('os.path.dirname')
+    def test_undeploy_instance_unregister_usage(self, mock_dirname,
+                                                mock_makedirs):
+        self.driver._get_state_file_path = mock.Mock(return_value='/path')
+        self.driver._unplug = mock.Mock()
+        mock_dirname.return_value = '/path/' + self.lb.id
+        with mock.patch.object(self._process_monitor,
+                               'unregister') as mock_unregister:
+            self.driver.undeploy_instance(self.lb.id)
+            mock_unregister.assert_called_once_with(
+                    uuid=self.lb.id, service_name='lbaas-ns-haproxy')
+
     @mock.patch('os.path.exists')
     @mock.patch('os.listdir')
     def test_remove_orphans(self, list_dir, exists):
@@ -423,11 +437,30 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             namespace=namespace_driver.get_ns_name(self.lb.id))
         mock_ns.netns.execute.assert_called_once_with(
             ['haproxy', '-f', conf_dir % 'haproxy.conf', '-p',
-             conf_dir % 'haproxy.pid'])
+             conf_dir % 'haproxy.pid'], addl_env=None, run_as_root=False)
         self.assertIn(self.lb.id, self.driver.deployed_loadbalancers)
         self.assertEqual(self.lb,
                          self.driver.deployed_loadbalancers[self.lb.id])
 
+    @mock.patch('neutron.common.utils.ensure_dir')
+    @mock.patch('neutron_lbaas.drivers.haproxy.jinja_cfg.save_config')
+    def test_spawn_enable_usage(self, jinja_save, ensure_dir):
+        with mock.patch.object(external_process.ProcessManager,
+                               'enable') as mock_enable:
+            self.driver._spawn(self.lb)
+            mock_enable.assert_called_once_with()
+
+    @mock.patch('neutron.common.utils.ensure_dir')
+    @mock.patch('neutron_lbaas.drivers.haproxy.jinja_cfg.save_config')
+    def test_spawn_reload_cfg_usage(self, jinja_save, ensure_dir):
+        with mock.patch.object(external_process.ProcessManager, 'active',
+                               return_value=True):
+            with mock.patch.object(external_process.ProcessManager,
+                                   'reload_cfg') as mock_reload_cfg:
+                extra_cmd_args = ['-sf', '123']
+                self.driver._spawn(self.lb, extra_cmd_args=extra_cmd_args)
+                mock_reload_cfg.assert_called_once_with()
+
 
 class BaseTestManager(base.BaseTestCase):
 
@@ -663,28 +696,6 @@ class TestHealthMonitorManager(BaseTestHealthMonitorManager):
 
 class TestNamespaceDriverModule(base.BaseTestCase):
 
-    @mock.patch('os.path.exists')
-    @mock.patch('neutron.agent.linux.utils.execute')
-    def test_kill_pids_in_file(self, execute, exists):
-        pid_path = '/var/lib/data'
-        with mock.patch('six.moves.builtins.open') as m_open:
-            exists.return_value = False
-            file_mock = mock.MagicMock()
-            m_open.return_value = file_mock
-            file_mock.__enter__.return_value = file_mock
-            file_mock.__iter__.return_value = iter(['123'])
-            namespace_driver.kill_pids_in_file(pid_path)
-            # sometimes fails
-            # exists.assert_called_once_with(pid_path)
-            self.assertFalse(m_open.called)
-            self.assertFalse(execute.called)
-
-            exists.return_value = True
-            execute.side_effect = RuntimeError
-            namespace_driver.kill_pids_in_file(pid_path)
-            # sometimes fails
-            # execute.assert_called_once_with(['kill', '-9', '123'])
-
     def test_get_ns_name(self):
         ns_name = namespace_driver.get_ns_name('woohoo')
         self.assertEqual(namespace_driver.NS_PREFIX + 'woohoo', ns_name)
